<?php 

if(!function_exists('get_wcfm_custom_menus_url')) {
	function get_wcfm_custom_menus_url( $endpoint ) {
		global $WCFM;
		$wcfm_page = get_wcfm_page();
		$wcfm_custom_menus_url = wcfm_get_endpoint_url( $endpoint, '', $wcfm_page );
		return $wcfm_custom_menus_url;
	}
}
// LOAD PLUGIN TEXTDOMAIN
function mtnft_addon_wcfm_load_textdomain() {
    load_plugin_textdomain( 'mtnft_addon_wcfm', false, plugin_basename( dirname( __FILE__ ) ) . '/languages' ); 
}

add_action( 'plugins_loaded', 'mtnft_addon_wcfm_load_textdomain' );

function mtnft_addon_wcfm_override_external_product_url( $url, $product ){
    global $post;
    if ( 'external' === $product->get_type() ) {
        // custom add to cart url example
        $vendorReff = get_user_meta( $post->post_author, '_mtnft_addon_wcfm_referral',1);
        $adminReff = get_option('mtnft')['referral'];
        $url = substr($url, 0, strpos($url, "?ref="));

        if(isset($vendorReff)  &&  $vendorReff != '') 
            $url = $url."?ref=".$vendorReff;
        else if(isset($adminReff)  && $adminReff != '')
            $url = $url."?ref=".$adminReff;
        else 
            $url;
    }
    return $url;
}

add_filter( 'woocommerce_product_add_to_cart_url', 'mtnft_addon_wcfm_override_external_product_url', 11, 2 );

/**
 * WCFM - Add Custom Menu
 */
function mtnft_addon_wcfm_menus( $menus ) {
	global $WCFM;

    if(wcfm_is_vendor(get_current_user_id()) || current_user_can('administrator')) {
        $custom_menus = array( 'nft-importer-import' => array(   
            'label'  => __('NFT Importer', 'mtnft_addon_wcfm'),
            'url'       => get_wcfm_custom_menus_url( 'nft-importer-import' ),
            'icon'      => 'cubes',
            'priority'  => 5.1
            ),
        );
        
        $menus = array_merge( $menus, $custom_menus );
    }
	return $menus;
}


add_filter( 'wcfm_menus', 'mtnft_addon_wcfm_menus', 20 );

/**
 *  WCFM - Custom Menus Views
 */
function mtnft_addon_wcfm_csm_load_views($end_point) {
	global $WCFM, $WCFMu;
	$plugin_path = trailingslashit( dirname( __FILE__  ) );
	switch( $end_point ) {
		case 'nft-importer-import': 
        {
            require_once( $plugin_path . 'views/importer.view.php' );
            break;
        }
    }
}
add_action( 'wcfm_load_views', 'mtnft_addon_wcfm_csm_load_views', 50 );
add_action( 'before_wcfm_load_views', 'mtnft_addon_wcfm_csm_load_views', 50 );

/**
 * WCFM - Custom Menus Query Var
 */
function mtnft_addon_wcfm_query_vars( $query_vars ) {
	$wcfm_modified_endpoints = (array) get_option( 'wcfm_endpoints' );
	
	$query_custom_menus_vars = array(
		'nft-importer-import' => ! empty( $wcfm_modified_endpoints['nft-importer-import'] ) ? $wcfm_modified_endpoints['nft-importer-import'] : 'nft-importer-import',
	);
	
	$query_vars = array_merge( $query_vars, $query_custom_menus_vars );
	
	return $query_vars;
}
add_filter( 'wcfm_query_vars', 'mtnft_addon_wcfm_query_vars', 50 );

/**
 * WCFM - Custom Menus End Point Title
 */
function mtnft_addon_wcfm_endpoint_title( $title, $endpoint ) {
	global $wp;
	switch ( $endpoint ) {
		case 'nft-importer-import' :
			$title = __( 'NFT Importer', 'mtnft_addon_wcfm' );
		break;
	}
	
	return $title;
}
add_filter( 'wcfm_endpoint_title', 'mtnft_addon_wcfm_endpoint_title', 50, 2 );

/**
 * WCFM - Custom Menus Endpoint Intialize
 */
function mtnft_addon_wcfm_init() {
	global $WCFM_Query;

	// Intialize WCFM End points
	$WCFM_Query->init_query_vars();
	$WCFM_Query->add_endpoints();
	
	if( !get_option( 'wcfm_updated_end_point_cms' ) ) {
		// Flush rules after endpoint update
		flush_rewrite_rules();
		update_option( 'wcfm_updated_end_point_cms', 1 );
	}


}
add_action( 'init', 'mtnft_addon_wcfm_init', 50 );

/**
 * WCFM - Custom Menus Endpoint Edit
 */
function mtnft_addon_wcfm_menus_endpoints_slug( $endpoints ) {
	
	$custom_menus_endpoints = array('nft-importer-import' => 'import',);
	
	$endpoints = array_merge( $endpoints, $custom_menus_endpoints );
	
	return $endpoints;
}
add_filter( 'wcfm_endpoints_slug', 'mtnft_addon_wcfm_menus_endpoints_slug' );


function mtnft_addon_wcfm_product_manage_fields($product_id = 0, $product_type) {
    global $wp, $WCFM, $WCFMu;
    $product_id = $wp->query_vars['wcfm-products-manage'];

    $_mtnft_sales = get_post_meta( $product_id, '_mtnft_sales', true );
    $_mtnft_presale = get_post_meta( $product_id, '_mtnft_presale', true ) == 0 ? false : true ;
    $_mtnft_collection_name = get_post_meta( $product_id, '_mtnft_collection', true )['name'];
    $_mtnft_currency_symbol = get_post_meta( $product_id, '_mtnft_currency_symbol', true );
    $_mtnft_currency_name = get_post_meta( $product_id, '_mtnft_currency_name', true );
    $_mtnft_currency_price = get_post_meta( $product_id, '_mtnft_currency_price', true );
    
    $wcsauction_fields = apply_filters( 'mtnft_roduct_manage_nft_fields', array( 
        "_mtnft_sales" => array('label' => __('Sales', 'mtnft_addon_wcfm') , 
                                'type' => 'text', 
                                'class' => 'wcfm-text', 
                                'label_class' => 'wcfm_title', 
                                'value' =>  $_mtnft_sales ,
                                'dfvalue' => $_mtnft_sales ),
        "_mtnft_presale" => array('label' => __('PreSale', 'mtnft_addon_wcfm') , 
                                'type' => 'checkbox', 
                                'class' => 'wcfm-checkbox wcfm_ele simple variable external grouped', 
                                'label_class' => 'wcfm_title', 
                                'value' =>  $_mtnft_presale  ,
                                'dfvalue' => $_mtnft_presale ),
        "_mtnft_collection_name" => array('label' => __('Collection Name', 'mtnft_addon_wcfm') , 
                                'type' => 'text', 
                                'class' => 'wcfm-text', 
                                'label_class' => 'wcfm_title', 
                                'value' =>  $_mtnft_collection_name ,
                                'dfvalue' => $_mtnft_collection_name ),
        "_mtnft_currency_symbol" => array('label' => __('Currency Symbol', 'mtnft_addon_wcfm') , 
                                'type' => 'text', 
                                'class' => 'wcfm-text', 
                                'label_class' => 'wcfm_title auction', 
                                'value' =>  $_mtnft_currency_symbol ,
                                'dfvalue' => $_mtnft_currency_symbol ),
        "_mtnft_currency_name" => array('label' => __('Currency Name', 'mtnft_addon_wcfm') , 
                                'type' => 'text', 
                                'class' => 'wcfm-text', 
                                'label_class' => 'wcfm_title auction', 
                                'value' =>  $_mtnft_currency_name ,
                                'dfvalue' => $_mtnft_currency_name ),
        "_mtnft_currency_price" => array('label' => __('Currency price', 'mtnft_addon_wcfm') , 
                                'type' => 'text', 
                                'class' => 'wcfm-text', 
                                'label_class' => 'wcfm_title auction', 
                                'value' =>  $_mtnft_currency_price ,
                                'dfvalue' => $_mtnft_currency_price ),
  ), $product_id );
    echo '<div class="page_collapsible products_manage_attribute simple variable external grouped booking collapse-close" id="wcfm_products_manage_form_attribute_head">
        <div class="page_collapsible_content_holder">
            <label class="wcfmfa fa-server"></label>
           '.__('NFT Settings','mtnft_addon_wcfm').'
        </div>
    </div>
    <div class="wcfm-container simple variable grouped external non-job_package non-resume_package non-auction non-groupbuy non-accommodation-booking" style="display: block;">
    <div id="wcfm_products_manage_form_inventory_expander" class="wcfm-content">
    ';
    $WCFM->wcfm_fields->wcfm_generate_form_field( $wcsauction_fields );
    echo '</div></div>';
}


add_filter( 'after_wcfm_products_manage_general', 'mtnft_addon_wcfm_product_manage_fields', 70, 2 );

add_action( 'after_wcfm_products_manage_meta_save', 'mtnft_addon_wcfm_product_meta_save', 80, 2 );

function mtnft_addon_wcfm_product_meta_save( $product_id, $wcfm_products_manage_form_data) {
    $keys = array_keys($wcfm_products_manage_form_data);
    foreach ( $keys as $key ) {
        if(strpos($key, '_mtnft_') === 0) {
            if($key === '_mtnft_collection_name') {
                $collection = get_post_meta(  $product_id, '_mtnft_collection')[0];
                $collection['name'] =  $wcfm_products_manage_form_data[ $key ] ;
                update_post_meta( $product_id, '_mtnft_collection', $collection );

            } else {
            update_post_meta( $product_id, $key, $wcfm_products_manage_form_data[ $key ] );
            }
        }
    }
}
//Product Single page  no more details when wcfm is active 
if(function_exists('mtnft_frontend'))
    add_action( 'woocommerce_single_product_summary', 'mtnft_frontend' );
if(function_exists('mtnft_frontend_meta'))
    add_action( 'woocommerce_single_product_summary', 'mtnft_frontend_meta' );